@@ -72,9 +72,9 @@ class VariableOsX11Resolution(Variable):
         Return current screen resolution (width, height).
         Try detect by xdpyinfo, then Xorg.log, xorg.conf
         """
-        #resolution = self.getResByXDpyInfo() or self.getResByXrandr()
-        #if resolution:
-            #return resolution
+        resolution = self.getResByXDpyInfo() or self.getResByXrandr()
+        if resolution:
+            return resolution
 
         if self.Get('os_root_type') != 'usb-hdd':
             xlog = "/var/log/Xorg.0.log"
